Criterion
----------

A criterion is used to determine the converence of a minimization procedure, such as if the
difference in consecutive loss function evaluation is small enough.


Hessian based
==============

.. autosummary::
    :toctree: _generated/criterion

    zfit.minimize.EDM
